#
# spec file for package python-pytest-console-scripts
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-console-scripts
Version:        1.4.1
Release:        3.4
Summary:        Pytest plugin for testing console scripts
License:        MIT
URL:            https://github.com/kvas-it/pytest-console-scripts
Source:         https://files.pythonhosted.org/packages/source/p/pytest-console-scripts/pytest-console-scripts-%{version}.tar.gz
BuildRequires:  %{python_module importlib-metadata >= 3.6 if %python-base < 3.10}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 4.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pytest >= 4.0.0
Requires:       (python-importlib-metadata >= 3.6 if python-base < 3.10)
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module virtualenv >= 20}
# /SECTION
%python_subpackages

%description
Pytest-console-scripts is a `Pytest`_ plugin for testing python scripts
installed via ``console_scripts`` entry point of ``setup.py``. It can run the
scripts under test in a separate process or using the interpreter that's
running the test suite.  The former mode ensures that the script will run in an
environment that is identical to normal execution whereas the latter one allows
much quicker test runs during development while simulating the real runs as
much as possible.

%prep
%autosetup -n pytest-console-scripts-%{version} -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cp tests/test_run_scripts.py template_run_scripts.py
export PYTHONDONTWRITEBYTECODE=1
%{python_expand #
export PYTHONPATH=%{buildroot}%{$python_sitelib}
sed 's|env python|$python|' template_run_scripts.py > tests/test_run_scripts.py
$python -m pytest -v
}

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/pytest_console_scripts
%{python_sitelib}/pytest_console_scripts-%{version}.dist-info

%changelog
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Fix requirements for python39 (yes really)
- Make brittle test "fix" depending on the undocumented value of
  unexpanded %%python_bin_suffix more robust
* Wed Jul 19 2023 ecsos <ecsos@opensuse.org>
- Fix build error for Leap.
* Thu Jun  1 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.1:
  * Dropped support for Python 3.7
  * Fix loading scripts with non-UTF-8 encodings.
  * Print output when a subprocess runner with `check=True` fails
    was missing.
  * Added type-hinting for all types,
    `pytest_console_scripts.ScriptRunner`
    can now be used to hint the `script_runner` fixture.
  * Added support for the `shell` and `check` keywords for in-
    process mode.
  * Passing command arguments in `*args` is now deprecated and
    will raise warnings.
  * Dropped support for Python 3.6
  * Install-time dependencies have been fixed.
* Mon Mar 21 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.3.1:
  * Remove use of mock.
- Drop patch remove-mock.patch, included upstream.
* Fri Mar 18 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.3:
  * Add a note on manual result printing to README - #50
  * Bump Python version to 3.6 - fix #51
- Add patch remove-mock.patch:
  * Remove use of mock.
* Fri Dec 17 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Wed Dec  8 2021 pgajdos@suse.com
- version update to 1.2.1
  * no upstream changelog
- deleted patches
  - virtualenv-20.patch (upstreamed)
* Wed Dec  8 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Fri May 15 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in pytest twice
* Mon Apr  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to work with python-virtualenv >= 20:
  * virtualenv-20.patch
* Fri Nov 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.0:
  * no upstream changelog
* Wed Sep 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update the pytest requirement to > 4 as per setup.py
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.1.10:
  * Print out return code, stdout and stderr output
* Thu Aug 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use spec-cleaner
- Update to 0.1.9:
  * Fixes for newer pytest releases
* Mon Oct  1 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to version 0.1.6
- Added pytest-console-scripts-0.1.6_test_virtualenv.patch
* Fri Jun 15 2018 Andreas Schneider <asn@cryptomilk.org>
- Initial package
